@@ -78,9 +78,9 @@ Returns the respective component of the parsed IRI.
 
 { 
 	package IRI; 
-	use v5.10;
+	use v5.10.1;
 	use warnings;
-	our $VERSION	= '0.008_01';
+	our $VERSION	= '0.008_02';
 	use Moo;
 	use MooX::HandlesVia;
 	use Types::Standard qw(Str InstanceOf HashRef Bool);
